import { __decorate } from 'tslib';
import { ViewChild, Input, Component, forwardRef, ViewEncapsulation, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { Plugin, PluginKey, EditorState } from 'prosemirror-state';
import { DecorationSet, Decoration, EditorView } from 'prosemirror-view';
import { Schema } from 'prosemirror-model';
import { nodes as nodes$1, marks } from 'prosemirror-schema-basic';
import { listItem as listItem$1, orderedList as orderedList$2, bulletList as bulletList$2, liftListItem, wrapInList, splitListItem, sinkListItem } from 'prosemirror-schema-list';
import { undo, redo, history } from 'prosemirror-history';
import { keymap } from 'prosemirror-keymap';
import { setBlockType, toggleMark, baseKeymap } from 'prosemirror-commands';
import { findSelectedNodeOfType, findParentNode } from 'prosemirror-utils';

var listGroup = 'block';
var listItem = Object.assign({}, listItem$1, { content: 'paragraph block*' });
var orderedList = Object.assign({}, orderedList$2, { content: 'list_item+', group: listGroup });
var bulletList = Object.assign({}, bulletList$2, { content: 'list_item+', group: listGroup });
var nodes = Object.assign({}, nodes$1, {
    list_item: listItem,
    ordered_list: orderedList,
    bullet_list: bulletList
});
var schema = new Schema({
    marks: marks,
    nodes: nodes
});

var isNodeActive = function (state, type, attrs) {
    if (attrs === void 0) { attrs = {}; }
    var _a = state.selection, $from = _a.$from, to = _a.to;
    var predicate = function (n) { return n.type === type; };
    var node = findSelectedNodeOfType(type)(state.selection) || findParentNode(predicate)(state.selection);
    if (!Object.entries(attrs).length || !node) {
        return !!node;
    }
    // check if heading is active
    return to <= $from.end() && $from.parent.hasMarkup(type, attrs);
};
var ɵ0 = isNodeActive;

var isMarkActive = function (state, type) {
    var _a = state.selection, from = _a.from, $from = _a.$from, to = _a.to, empty = _a.empty;
    if (empty) {
        return !!type.isInSet(state.storedMarks || $from.marks());
    }
    else {
        return state.doc.rangeHasMark(from, to, type);
    }
};
var ɵ0$1 = isMarkActive;

function toggleList(type, itemType) {
    return function (state, dispatch) {
        var isActive = isNodeActive(state, type);
        if (isActive) {
            return liftListItem(itemType)(state, dispatch);
        }
        return wrapInList(type)(state, dispatch);
    };
}

function toggleBlockType(type, toggleType, attrs) {
    if (attrs === void 0) { attrs = {}; }
    return function (state, dispatch) {
        var isActive = isNodeActive(state, type, attrs);
        if (isActive) {
            return setBlockType(toggleType)(state, dispatch);
        }
        return setBlockType(type, attrs)(state, dispatch);
    };
}

/* tslint:disable */
var bold = "\n  <path d=\"M15.6 10.79c.97-.67 1.65-1.77 1.65-2.79 0-2.26-1.75-4-4-4H7v14h7.04c2.09 0 3.71-1.7 3.71-3.79 0-1.52-.86-2.82-2.15-3.42zM10 6.5h3c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5h-3v-3zm3.5 9H10v-3h3.5c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5z\" />\n  <path d=\"M0 0h24v24H0z\" fill=\"none\" />\n";

var italic = "\n  <path d=\"M0 0h24v24H0z\" fill=\"none\" />\n  <path d=\"M10 4v3h2.21l-3.42 8H6v3h8v-3h-2.21l3.42-8H18V4z\" />\n";

var code = "\n<path d=\"M0 0h24v24H0V0z\" fill=\"none\"/>\n<path d=\"M9.4 16.6L4.8 12l4.6-4.6L8 6l-6 6 6 6 1.4-1.4zm5.2 0l4.6-4.6-4.6-4.6L16 6l6 6-6 6-1.4-1.4z\"/>\n";

var orderedList$1 = "\n<path d=\"M2 17h2v.5H3v1h1v.5H2v1h3v-4H2v1zm1-9h1V4H2v1h1v3zm-1 3h1.8L2 13.1v.9h3v-1H3.2L5 10.9V10H2v1zm5-6v2h14V5H7zm0 14h14v-2H7v2zm0-6h14v-2H7v2z\"/>\n<path d=\"M0 0h24v24H0z\" fill=\"none\"/>\n";

var bulletList$1 = "\n<path d=\"M0 0h24v24H0V0z\" fill=\"none\"/>\n<path d=\"M4 10.5c-.83 0-1.5.67-1.5 1.5s.67 1.5 1.5 1.5 1.5-.67 1.5-1.5-.67-1.5-1.5-1.5zm0-6c-.83 0-1.5.67-1.5 1.5S3.17 7.5 4 7.5 5.5 6.83 5.5 6 4.83 4.5 4 4.5zm0 12c-.83 0-1.5.68-1.5 1.5s.68 1.5 1.5 1.5 1.5-.68 1.5-1.5-.67-1.5-1.5-1.5zM7 19h14v-2H7v2zm0-6h14v-2H7v2zm0-8v2h14V5H7z\"/>\n";

var arrowDropDown = "\n<path d=\"M7 10l5 5 5-5z\"/><path d=\"M0 0h24v24H0z\" fill=\"none\"/>\n";

// Icons source: https://material.io/
var DEFAULT_ICON_HEIGHT = 20;
var DEFAULT_ICON_WIDTH = 20;
var icons = {
    bold: bold,
    italic: italic,
    code: code,
    ordered_list: orderedList$1,
    bullet_list: bulletList$1,
    arrow_drop_down: arrowDropDown
};
// Helper function to create menu icons
function getIconSvg(name, width, height) {
    if (width === void 0) { width = DEFAULT_ICON_WIDTH; }
    if (height === void 0) { height = DEFAULT_ICON_HEIGHT; }
    var path = icons[name] || '<path></path>';
    return "\n  <svg\n    xmlns=\"http://www.w3.org/2000/svg\"\n    viewBox=\"0 0 24 24\"\n    fill=\"black\"\n    height=" + height + "\n    width=" + width + "\n  >\n    " + path + "\n  </svg>\n  ";
}

var flatDeep = function (arr, d) {
    if (d === void 0) { d = 1; }
    return d > 0
        ? arr.reduce(function (acc, val) { return acc.concat(Array.isArray(val) ? flatDeep(val, d - 1) : val); }, [])
        : arr.slice();
};
var ɵ0$2 = flatDeep;

var menuItemsMeta = {
    bold: {
        key: 'strong',
        icon: 'bold',
        type: 'mark',
    },
    italic: {
        key: 'em',
        icon: 'italic',
        type: 'mark',
    },
    code: {
        key: 'code',
        icon: 'code',
        type: 'mark',
    },
    ordered_list: {
        key: 'ordered_list',
        icon: 'ordered_list',
        type: 'node',
    },
    bullet_list: {
        key: 'bullet_list',
        icon: 'bullet_list',
        type: 'node',
    },
    h1: {
        key: 'heading',
        attrs: {
            level: 1,
        },
        type: 'node'
    },
    h2: {
        key: 'heading',
        attrs: {
            level: 2,
        },
        type: 'node'
    },
    h3: {
        key: 'heading',
        attrs: {
            level: 3,
        },
        type: 'node'
    },
    h4: {
        key: 'heading',
        attrs: {
            level: 4,
        },
        type: 'node'
    },
    h5: {
        key: 'heading',
        attrs: {
            level: 5,
        },
        type: 'node'
    },
    h6: {
        key: 'heading',
        attrs: {
            level: 6,
        },
        type: 'node'
    }
};

var labels = {
    bold: 'Bold',
    italics: 'Italics',
    code: 'Code',
    ordered_list: 'Ordered List',
    bullet_list: 'Bullet List',
    heading: 'Heading'
};

var MENU_ITEM_CLASSNAME = 'NgxEditor-MenuItem';
var DROPDOWN_ITEMS = new Map();
DROPDOWN_ITEMS.set('heading', ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']);
var isListItem = function (type) {
    return (type === schema.nodes.list_item ||
        type === schema.nodes.ordered_list ||
        type === schema.nodes.bullet_list);
};
var ɵ0$3 = isListItem;
var DropDownView = /** @class */ (function () {
    function DropDownView(dropdownGroup, dropdownFields, editorView) {
        this.updates = [];
        this.dropdownGroup = dropdownGroup;
        this.dropdownFields = dropdownFields;
        this.editorView = editorView;
    }
    DropDownView.prototype.getWrapperDom = function () {
        var _this = this;
        var isDropdownOpen = false;
        var dropdownWrapper = document.createElement('div');
        dropdownWrapper.classList.add(MENU_ITEM_CLASSNAME);
        dropdownWrapper.classList.add(MENU_ITEM_CLASSNAME + "__Dropdown-Wrapper");
        // create dropdown content
        var dropdown = document.createElement('div');
        dropdown.classList.add(MENU_ITEM_CLASSNAME + "__Dropdown");
        var dropdownText = document.createElement('div');
        dropdownText.classList.add(MENU_ITEM_CLASSNAME + "__Dropdown-Text");
        dropdownText.textContent = labels[this.dropdownGroup];
        var dropdownIcon = document.createElement('div');
        dropdownIcon.classList.add(MENU_ITEM_CLASSNAME + "__Dropdown-Icon");
        dropdownIcon.innerHTML = getIconSvg('arrow_drop_down');
        dropdown.appendChild(dropdownText);
        dropdown.appendChild(dropdownIcon);
        var dropdownOpenClassName = MENU_ITEM_CLASSNAME + "__Dropdown-Wrapper-Open";
        var mouseDownHandler = function (e) {
            e.preventDefault();
            if (!dropdownWrapper.contains(e.target)) {
                closeDropdown();
            }
        };
        var openDropdown = function () {
            dropdownWrapper.classList.add(dropdownOpenClassName);
            isDropdownOpen = true;
            window.addEventListener('mousedown', mouseDownHandler);
        };
        var closeDropdown = function () {
            dropdownWrapper.classList.remove(dropdownOpenClassName);
            isDropdownOpen = false;
            window.removeEventListener('mousedown', mouseDownHandler);
        };
        dropdown.addEventListener('click', function (e) {
            e.preventDefault();
            if (!isDropdownOpen) {
                openDropdown();
            }
            else {
                closeDropdown();
            }
        });
        // create dropdown list
        var dropdownList = document.createElement('div');
        dropdownList.classList.add(MENU_ITEM_CLASSNAME + "__Dropdown-Menu");
        this.dropdownFields.forEach(function (dropdownItem) {
            var menuItem = menuItemsMeta[dropdownItem];
            var text = labels[menuItem.key];
            if (menuItem.key === 'heading') {
                text += " " + menuItem.attrs.level;
            }
            var spec = {
                classNames: [
                    MENU_ITEM_CLASSNAME + "__Dropdown-Item"
                ],
                textContent: text,
                attrs: {
                    title: text
                }
            };
            var menuItemView = new MenuItemView(menuItem, _this.editorView, spec);
            var _a = menuItemView.render(), update = _a.update, dom = _a.dom;
            // remove open class once clicked on dropdown value
            dom.addEventListener('click', function (e) {
                e.preventDefault();
                closeDropdown();
            });
            // wrapper to execute when update is called
            var dropUpdate = function (state) {
                update(state);
                var selectedClass = MENU_ITEM_CLASSNAME + "__Dropdown-Wrapper-Selected";
                // update the dropdown content heading when a class is selected
                var activeEl = dropdownList.getElementsByClassName(MENU_ITEM_CLASSNAME + "__Active");
                if (activeEl.length) {
                    var el = activeEl[0];
                    dropdownText.textContent = el.textContent;
                    dropdownWrapper.classList.add(selectedClass);
                }
                else {
                    // restore default value
                    dropdownText.textContent = labels[_this.dropdownGroup];
                    dropdownWrapper.classList.remove(selectedClass);
                }
            };
            dropdownList.appendChild(dom);
            _this.updates.push(dropUpdate);
        });
        dropdownWrapper.appendChild(dropdown);
        dropdownWrapper.appendChild(dropdownList);
        return dropdownWrapper;
    };
    DropDownView.prototype.render = function () {
        this.dom = this.getWrapperDom();
        return {
            dom: this.dom,
            updates: this.updates
        };
    };
    return DropDownView;
}());
var MenuItemView = /** @class */ (function () {
    function MenuItemView(menuItem, editorView, spec) {
        this.menuItem = menuItem;
        this.editorView = editorView;
        this.spec = spec;
    }
    MenuItemView.prototype.render = function () {
        var _this = this;
        var dom = this.dom = this.getDom();
        this.setupCommandListeners();
        var update = function (state) {
            var menuItem = _this.menuItem;
            var isActive = false;
            if (menuItem.type === 'mark') {
                var type = schema.marks[menuItem.key];
                isActive = isMarkActive(state, type);
            }
            if (menuItem.type === 'node') {
                var type = schema.nodes[menuItem.key];
                isActive = isNodeActive(state, type, menuItem.attrs);
            }
            dom.classList.toggle(MENU_ITEM_CLASSNAME + "__Active", isActive);
        };
        return {
            dom: dom,
            update: update
        };
    };
    MenuItemView.prototype.getDom = function () {
        var div = document.createElement('div');
        if (this.spec.classNames) {
            this.spec.classNames.forEach(function (className) {
                div.classList.add(className);
            });
        }
        if (this.spec.attrs) {
            Object.entries(this.spec.attrs).forEach(function (obj) {
                div.setAttribute(obj[0], obj[1]);
            });
        }
        if (this.spec.innerHTML) {
            div.innerHTML = this.spec.innerHTML;
        }
        if (this.spec.textContent) {
            div.innerHTML = this.spec.textContent;
        }
        return div;
    };
    MenuItemView.prototype.setupCommandListeners = function () {
        var _this = this;
        this.dom.addEventListener('mousedown', function (e) {
            e.preventDefault();
            // don't execute if not left click
            if (e.buttons !== 1) {
                return;
            }
            if (_this.menuItem.type === 'mark') {
                var command = toggleMark(schema.marks[_this.menuItem.key]);
                command(_this.editorView.state, _this.editorView.dispatch);
                return;
            }
            if (_this.menuItem.type === 'node') {
                var type = schema.nodes[_this.menuItem.key];
                if (isListItem(type)) {
                    var command = toggleList(type, schema.nodes.list_item);
                    command(_this.editorView.state, _this.editorView.dispatch);
                    return;
                }
                if (type === schema.nodes.heading) {
                    var command = toggleBlockType(type, schema.nodes.paragraph, { level: _this.menuItem.attrs.level });
                    command(_this.editorView.state, _this.editorView.dispatch);
                    return;
                }
            }
        });
    };
    return MenuItemView;
}());
var getSeperatorDom = function () {
    var div = document.createElement('div');
    div.className = MENU_ITEM_CLASSNAME + "__Seperator";
    return div;
};
var ɵ1 = getSeperatorDom;
var renderMenu = function (toolbar, editorView, menuDom) {
    var updates = [];
    toolbar.forEach(function (group, toolbarIndex) {
        var isLastMenuGroup = toolbar.length - 1 === toolbarIndex;
        group.forEach(function (toolbarItem, menuIndex) {
            var isLastMenuItem = group.length - 1 === menuIndex;
            // render dropdown
            if (typeof toolbarItem === 'object') {
                Object.keys(toolbarItem).forEach(function (dropdownGroup) {
                    if (DROPDOWN_ITEMS.has(dropdownGroup)) {
                        var dropdown = toolbarItem[dropdownGroup];
                        var dropdownView = new DropDownView(dropdownGroup, dropdown, editorView);
                        var rendered = dropdownView.render();
                        updates.push(rendered.updates);
                        menuDom.appendChild(rendered.dom);
                    }
                    else {
                        console.warn('Unkown dropdown group:', dropdownGroup);
                    }
                });
            }
            // render Icons
            if (typeof toolbarItem === 'string') {
                var menuItem = menuItemsMeta[toolbarItem];
                if (menuItem) {
                    var spec = {
                        classNames: [
                            MENU_ITEM_CLASSNAME,
                            MENU_ITEM_CLASSNAME + "__Icon",
                            MENU_ITEM_CLASSNAME + "__" + menuItem.key
                        ],
                        innerHTML: getIconSvg(menuItem.icon),
                        attrs: {
                            title: menuItem.key
                        }
                    };
                    var menuItemView = new MenuItemView(menuItem, editorView, spec);
                    var _a = menuItemView.render(), update = _a.update, dom = _a.dom;
                    menuDom.appendChild(dom);
                    updates.push(update);
                }
            }
            if (isLastMenuItem && !isLastMenuGroup) {
                var seperatorDom = getSeperatorDom();
                menuDom.appendChild(seperatorDom);
            }
        });
    });
    var combinedUpdates = flatDeep(updates, Infinity);
    return {
        update: function (state) {
            combinedUpdates.forEach(function (update) {
                update(state);
            });
        }
    };
};

var MenuBarView = /** @class */ (function () {
    function MenuBarView(toolbar, editorView) {
        // const menu = getMenu(toolbar);
        this.view = editorView;
        this.toolbar = toolbar;
        this.render();
        this.update();
    }
    MenuBarView.prototype.render = function () {
        var menuDom = document.createElement('div');
        menuDom.className = 'NgxEditor-MenuBar';
        var update = renderMenu(this.toolbar, this.view, menuDom).update;
        this.updateMenuItems = update;
        this.view.dom.parentNode.insertBefore(menuDom, this.view.dom);
    };
    MenuBarView.prototype.update = function () {
        this.updateMenuItems(this.view.state);
    };
    return MenuBarView;
}());

function menuPlugin(toolbar) {
    return new Plugin({
        key: new PluginKey('menu'),
        view: function (editorView) {
            return new MenuBarView(toolbar, editorView);
        },
    });
}
var menu = function (toolbarOptions) {
    return menuPlugin(toolbarOptions);
};
var ɵ0$4 = menu;

function placeholderPlugin(text) {
    return new Plugin({
        key: new PluginKey('placeholder'),
        props: {
            decorations: function (state) {
                var doc = state.doc;
                if (doc.childCount === 1 && doc.firstChild.isTextblock && doc.firstChild.content.size === 0) {
                    var placeHolderEl = document.createElement('span');
                    placeHolderEl.classList.add('NgxEditor-Placeholder');
                    placeHolderEl.textContent = text;
                    return DecorationSet.create(doc, [Decoration.widget(1, placeHolderEl)]);
                }
                return DecorationSet.empty;
            }
        }
    });
}

var isMacOs = /Mac/.test(navigator.platform);
var getHistoryKeyMap = function () {
    var historyMap = {};
    historyMap['Mod-z'] = undo;
    if (isMacOs) {
        historyMap['Shift-Mod-z'] = redo;
    }
    else {
        historyMap['Mod-y'] = redo;
    }
    return historyMap;
};
var ɵ0$5 = getHistoryKeyMap;
var getListKeyMap = function () {
    var listMap = {};
    listMap.Enter = splitListItem(schema.nodes.list_item);
    listMap['Mod-['] = liftListItem(schema.nodes.list_item);
    listMap['Mod-]'] = sinkListItem(schema.nodes.list_item);
    listMap.Tab = sinkListItem(schema.nodes.list_item);
    return listMap;
};
var ɵ1$1 = getListKeyMap;
var getPlugins = function (options) {
    var historyKeyMap = getHistoryKeyMap();
    var listKeyMap = getListKeyMap();
    var plugins = [
        history(),
        keymap({
            'Mod-b': toggleMark(schema.marks.strong),
            'Mod-i': toggleMark(schema.marks.em),
            'Mod-`': toggleMark(schema.marks.code),
        }),
        keymap(historyKeyMap),
        keymap(listKeyMap),
        keymap(baseKeymap),
        placeholderPlugin(options.placeholder),
    ];
    if (options.toolbar) {
        plugins.push(menu(options.toolbar));
    }
    return plugins;
};

var defaultToolbarOptions = [
    ['bold', 'italic'],
    ['code'],
    ['ordered_list', 'bullet_list'],
    [{ heading: ['h1', 'h2', 'h3', 'h4', 'h5', 'h6'] }]
];
var defaultConfig = {
    toolbar: true
};
var getToolbar = function (config) {
    var toolbar = null;
    // set toolbar options
    if (typeof config.toolbar === 'boolean') {
        if (config.toolbar) {
            toolbar = defaultToolbarOptions;
        }
    }
    else {
        toolbar = config.toolbar;
    }
    return toolbar;
};
var ɵ0$6 = getToolbar;
// prefer attributes to config
var computeOptions = function (options) {
    var computedOptions = {};
    var config = Object.assign({}, defaultConfig, options.config);
    computedOptions.toolbar = getToolbar(config);
    if (options.placeholder) {
        computedOptions.placeholder = options.placeholder;
    }
    return computedOptions;
};
var ɵ1$2 = computeOptions;

var NgxEditorComponent = /** @class */ (function () {
    function NgxEditorComponent() {
        this.placeholder = 'Type here...';
    }
    NgxEditorComponent_1 = NgxEditorComponent;
    NgxEditorComponent.prototype.writeValue = function (value) {
        if (!value) {
            return;
        }
        this.updateContent(value);
    };
    NgxEditorComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    NgxEditorComponent.prototype.registerOnTouched = function () { };
    NgxEditorComponent.prototype.parseDoc = function (contentJson) {
        return schema.nodeFromJSON(contentJson);
    };
    NgxEditorComponent.prototype.updateContent = function (value) {
        try {
            var doc = this.parseDoc(value);
            var state = this.view.state;
            var tr = state.tr;
            tr.replaceWith(0, state.doc.content.size, doc);
            this.view.dispatch(tr);
        }
        catch (err) {
            console.error('Unable to update document.', err);
        }
    };
    NgxEditorComponent.prototype.handleTransactions = function (tr) {
        var state = this.view.state.applyTransaction(tr).state;
        this.view.updateState(state);
        if (tr.docChanged) {
            var json = state.doc.toJSON();
            this.onChange(json);
        }
    };
    NgxEditorComponent.prototype.createEditor = function () {
        this.view = new EditorView(this.ngxEditor.nativeElement, {
            state: EditorState.create({
                schema: schema,
                plugins: getPlugins(this.options),
            }),
            dispatchTransaction: this.handleTransactions.bind(this),
            attributes: {
                class: 'NgxEditor-Content'
            },
        });
    };
    NgxEditorComponent.prototype.ngOnInit = function () {
        this.options = computeOptions({
            placeholder: this.placeholder,
            config: this.config
        });
        this.createEditor();
    };
    NgxEditorComponent.prototype.ngOnDestroy = function () {
        this.view.destroy();
    };
    var NgxEditorComponent_1;
    __decorate([
        ViewChild('ngxEditor', { static: true })
    ], NgxEditorComponent.prototype, "ngxEditor", void 0);
    __decorate([
        Input()
    ], NgxEditorComponent.prototype, "placeholder", void 0);
    __decorate([
        Input()
    ], NgxEditorComponent.prototype, "config", void 0);
    NgxEditorComponent = NgxEditorComponent_1 = __decorate([
        Component({
            selector: 'ngx-editor',
            template: "<div class=\"NgxEditor-Wrapper\" #ngxEditor></div>\n",
            providers: [{
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return NgxEditorComponent_1; }),
                    multi: true
                }],
            encapsulation: ViewEncapsulation.None,
            styles: [".ProseMirror{outline:0}.NgxEditor-Wrapper{background:padding-box #fff;color:#000;border-radius:4px;border:2px solid rgba(0,0,0,.2)}.NgxEditor-MenuBar{display:flex;padding:.2rem;border-bottom:1px solid #ddd}.NgxEditor-MenuBar .NgxEditor-MenuItem{display:flex;align-items:center;justify-content:center}.NgxEditor-MenuBar .NgxEditor-MenuItem:hover{cursor:pointer;background-color:#f1f1f1}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Icon{height:30px;width:30px;transition:.3s ease-in-out;border-radius:2px;margin-right:2px}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Icon.NgxEditor-MenuItem__Active{background-color:#e8f0fe}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Icon.NgxEditor-MenuItem__Active svg{fill:#1a73e8}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper{position:relative;max-width:100px;width:100%;justify-content:start}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown{display:flex;align-items:center;width:100%}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown .NgxEditor-MenuItem__Dropdown-Text{margin-left:5px}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown .NgxEditor-MenuItem__Dropdown-Icon{margin-left:auto;position:relative;top:2px}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown-Menu{position:absolute;left:0;top:30px;box-shadow:rgba(60,64,67,.15) 0 2px 6px 2px;border-radius:4px;background-color:#fff;display:none}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown-Menu .NgxEditor-MenuItem__Dropdown-Item{cursor:pointer;padding:.5rem 1rem;white-space:nowrap}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown-Menu .NgxEditor-MenuItem__Dropdown-Item.NgxEditor-MenuItem__active,.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper .NgxEditor-MenuItem__Dropdown-Menu .NgxEditor-MenuItem__Dropdown-Item:hover{background-color:#f1f1f1}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper.NgxEditor-MenuItem__Dropdown-Wrapper-Open,.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper.NgxEditor-MenuItem__Dropdown-Wrapper-Selected{background-color:#e8f0fe;color:#1a73e8}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper.NgxEditor-MenuItem__Dropdown-Wrapper-Open .NgxEditor-MenuItem__Dropdown-Icon svg{fill:#1a73e8}.NgxEditor-MenuBar .NgxEditor-MenuItem.NgxEditor-MenuItem__Dropdown-Wrapper.NgxEditor-MenuItem__Dropdown-Wrapper-Open .NgxEditor-MenuItem__Dropdown-Menu{display:block;color:initial}.NgxEditor-MenuBar .NgxEditor-MenuItem__Seperator{border-left:1px solid #ccc;margin:0 5px}.NgxEditor-Content{padding:.5rem;white-space:pre-wrap}.NgxEditor-Content p{margin:0 0 .7rem}.NgxEditor-Placeholder{color:#6c757d;opacity:1}"]
        })
    ], NgxEditorComponent);
    return NgxEditorComponent;
}());

var NgxEditorModule = /** @class */ (function () {
    function NgxEditorModule() {
    }
    NgxEditorModule = __decorate([
        NgModule({
            declarations: [NgxEditorComponent],
            exports: [NgxEditorComponent],
        })
    ], NgxEditorModule);
    return NgxEditorModule;
}());

/*
 * Public API Surface of ngx-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxEditorComponent, NgxEditorModule, schema };
//# sourceMappingURL=ngx-editor.js.map
